@@ -31,14 +31,4 @@ class EigenRecipe(GitCmakeRecipe):
     # os_dependencies = { 'required': {'ubuntu': "space separated packet names", 'centos': "..."},
     #                     'optional': {'ubuntu': "space separated packet names", 'centos': "..."}
     # The idea behind is to generate easy to use instructions: 'sudo apt-get install ... ... ... '
-    os_dependencies = {
-        'required': {
-            'ubuntu': "",
-            'centos': "",
-            'centos8': ""
-        },
-        'optional': {
-            'ubuntu': "",
-            'centos': ""
-        },
-    }
+    os_dependencies = {}
